marktools.is_component_with_noncontext_mark_attached
====================================================

.. autofunction:: abjad.tools.marktools.is_component_with_noncontext_mark_attached.is_component_with_noncontext_mark_attached
